@@ -413,7 +413,7 @@ class HandlerWorker:
     def process(self):
         try:
             path = self.path and Pathy.fluid(self.path)
-            ds = self.ds or pydicom.dcmread(self.f or path.open())
+            ds = self.ds or pydicom.dcmread(self.f or path.open('rb'), force=True)
             params = self.file_params(ds, ae_title=self.ae_title, filename=getattr(path, 'stem', None))
             logger.info(f'processing {params}')
             extracted = self.args.extracted
@@ -574,6 +574,11 @@ def read_args():
         action='store_true',
         help='Will cause all PS/SC files to contain just one measurement each, instead of all for the frame',
     )
+    parser.add_argument(
+        '--sync-search',
+        default=['reportCompleted=true'],
+        help='Parameters for sync search, can be used to sync only when special criteria is met',
+    )
     parser.add_argument(
         '--username',
         help='App username',
